Here you find the code reference for the main components of `PyStemmusScope`.

## **Run the model**:

::: PyStemmusScope.stemmus_scope.StemmusScope
    options:
      show_root_heading: false
      show_source: true
      heading_level: 3
      members_order: source

## **Post processing**:

::: PyStemmusScope.save
    options:
      show_root_heading: true
      show_source: true
      heading_level: 3

## **BMI interface**:

::: PyStemmusScope.bmi.StemmusScopeBmi
    options:
      show_root_heading: true
      show_source: true
      heading_level: 3
      members_order: source
